/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.operator.keycloak.user;

import java.io.IOException;

import org.keycloak.common.util.Base64;
import org.springframework.stereotype.Component;

import io.fabric8.kubernetes.api.model.Secret;

@Component
class UserSecretReader {

	public String getPasswortFromSecret(Secret secret) {
		String encodedPassword = secret.getData().get(UserSecretBuilder.SECRET_PASSWORD_FIELD);
		return decode(encodedPassword, secret);
	}

	private String decode(String encodedPassword, Secret secret) {
		try {
			return new String(Base64.decode(encodedPassword));
		} catch (IOException e) {
			throw new RuntimeException("Could not decode content from secret (base64) for secret " + secret.getFullResourceName(), e);
		}
	}
}
