/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.group;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.operator.keycloak.KeycloakGenericRemoteService;

class KeycloakGroupPreconditionServiceTest {

	@Spy
	@InjectMocks
	private KeycloakGroupPreconditionService service;

	@Mock
	private KeycloakGenericRemoteService genericRemoteService;

	@Nested
	class TestReconcilePreconditionsMet {

		@Test
		void shouldCallRealmExists() {
			when(genericRemoteService.realmExists(any())).thenReturn(false);

			service.getReconcilePreconditionErrors(OzgCloudKeycloakGroupTestFactory.create());

			verify(genericRemoteService).realmExists(OzgCloudKeycloakGroupTestFactory.METADATA_NAMESPACE);
		}

		@Test
		void shouldReturnErrorIfRealmNotExists() {
			doReturn(false).when(genericRemoteService).realmExists(anyString());

			var response = service.getReconcilePreconditionErrors(OzgCloudKeycloakGroupTestFactory.create());

			assertThat(response).isPresent();
		}

		@Test
		void shouldReturnEmptyIfRealmExists() {
			doReturn(true).when(genericRemoteService).realmExists(anyString());

			var response = service.getReconcilePreconditionErrors(OzgCloudKeycloakGroupTestFactory.create());

			assertThat(response).isEmpty();
		}
	}
}
